@@ -6,19 +6,24 @@ import subprocess
 import acme_tiny
 
 
-def generate_cert(domain, cert_dir="certs"):
+def generate_cert(domain, certs_dir="certs"):
     """Generate a TLS certificate signed by Let's Encrypt for given domain."""
-    cert_dir = pathlib.Path(cert_dir) / domain
-    cert_dir.mkdir(exist_ok=True)
-    account_key = cert_dir / "account.key"
+    certs_dir = pathlib.Path(certs_dir)
+    challenge_dir = certs_dir / "challenges"
+    challenge_dir.mkdir(exist_ok=True, parents=True)
+
+    account_key = certs_dir / "account.key"
     if not account_key.exists():
         with account_key.open("w") as fp:
             subprocess.call(["openssl", "genrsa", "4096"], stdout=fp)
-    private_key = cert_dir / "domain.key"
+
+    domain_dir = certs_dir / domain
+    domain_dir.mkdir(exist_ok=True)
+    private_key = domain_dir / "domain.key"
     if not private_key.exists():
         with private_key.open("w") as fp:
             subprocess.call(["openssl", "genrsa", "4096"], stdout=fp)
-    csr = cert_dir / "domain.csr"
+    csr = domain_dir / "domain.csr"
     if not csr.exists():
         with csr.open("w") as fp:
             subprocess.call(
@@ -36,8 +41,5 @@ def generate_cert(domain, cert_dir="certs"):
                 ],
                 stdout=fp,
             )
-    challenge_dir = cert_dir / "challenges"
-    challenge_dir.mkdir(exist_ok=True)
-    with (cert_dir / "domain.crt").open("w") as fp:
+    with (domain_dir / "domain.crt").open("w") as fp:
         fp.write(acme_tiny.get_crt(account_key, csr, challenge_dir))
-    # XXX csr.unlink()
