@@ -428,7 +428,7 @@ class Machine(MachineBase):
         )
         self.run(
             f"cat > {self.nginx_conf}/nginx.conf",
-            stdin=str(templates.nginx(self.address, [self.onion], {})),
+            stdin=str(templates.nginx(self.run_dir, self.address, [self.onion], {})),
         )
         self.run(f"chown gaea:gaea {self.nginx_conf}/nginx.conf")
 
